pm4py.evaluation.earth\_mover\_distance package
===============================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.evaluation.earth_mover_distance.variants

Submodules
----------

pm4py.evaluation.earth\_mover\_distance.evaluator module
--------------------------------------------------------

.. automodule:: pm4py.evaluation.earth_mover_distance.evaluator
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.evaluation.earth_mover_distance
   :members:
   :undoc-members:
   :show-inheritance:
